@@ -14,11 +14,21 @@
 """Testing support
 """
 __docformat__ = 'restructuredtext'
-
+import re
 from zope import component
+from zope.testing import renormalizing
+
+from .annotatableadapter import ZDCAnnotatableAdapter
+from .interfaces import IWriteZopeDublinCore
+
+checker = renormalizing.RENormalizing([
+    # Python 3 unicode removed the "u".
+    (re.compile("u('.*?')"),
+     r"\1"),
+    (re.compile('u(".*?")'),
+     r"\1"),
+    ])
 
-from annotatableadapter import ZDCAnnotatableAdapter
-from interfaces import IWriteZopeDublinCore
 
 def setUpDublinCore():
     component.provideAdapter(ZDCAnnotatableAdapter,
